@@ -13,6 +13,7 @@ import platform
 import sys
 from pathlib import Path
 
+import robot
 from docgen import finder, loader, patcher, converter
 from docgen.utils import timed, debug_traceback
 
@@ -72,8 +73,10 @@ def convert(args, match):
         if not args.no_patches:
             patcher.apply_all(lib)
         converter.convert(lib, args.format, args.output)
+        return True
     except ImportError:
         debug_traceback()
+        return False
 
 
 def create_parser():
@@ -117,6 +120,10 @@ def create_parser():
         action="store_true",
         help="Don't parse resources from current directory",
     )
+    parser.add_argument(
+        "--template",
+        help="HTML template for library documentation page"
+    )
     parser.add_argument(
         "-v", "--verbose", help="be more talkative", action="store_true"
     )
@@ -134,6 +141,15 @@ def run(raw_args=None):
         format="%(asctime)s %(levelname)-8s %(message)s",
     )
 
+    if args.template:
+        template = Path(args.template).resolve()
+        if not template.is_file():
+            parser.error("Template is not a file")
+
+        logging.info("Using HTML template: %s", template)
+        robot.htmldata.LIBDOC = str(template)
+        robot.libdocpkg.htmlwriter.LIBDOC = str(template)
+
     with timed("All"):
         with timed("Find"):
             matches, include = find(args)
@@ -150,6 +166,6 @@ def run(raw_args=None):
         with timed("Convert"):
             count = 0
             for match in matches:
-                convert(args, match)
-                count += 1
+                if convert(args, match):
+                    count += 1
             logging.info("Created %d file(s)", count)
