@@ -7,9 +7,7 @@ from pathlib import Path
 from robot.libdocpkg import htmlwriter
 from robot.libdocpkg.model import LibraryDoc
 from docgen import rest
-from robot.version import VERSION
-
-RF_VERSION = VERSION
+from robot.version import VERSION as ROBOT_VERSION
 
 # Populated dynamically
 CONVERTERS = {}
@@ -64,7 +62,7 @@ class JsonConverter(BaseConverter):
             return doc
 
     def convert(self, libdoc: LibraryDoc, output):
-        if int(RF_VERSION[0]) <= 3:
+        if int(ROBOT_VERSION[0]) <= 3:
             data = htmlwriter.JsonConverter(self._NullFormatter()).convert(libdoc)
             with open(output, "w") as fd:
                 json.dump(data, fd, indent=4)
@@ -77,7 +75,7 @@ class JsonHtmlConverter(BaseConverter):
     EXTENSION = ".json"
 
     def convert(self, libdoc: LibraryDoc, output):
-        if int(RF_VERSION[0]) <= 3:
+        if int(ROBOT_VERSION[0]) <= 3:
             formatter = htmlwriter.DocFormatter(
                 libdoc.keywords, libdoc.doc, libdoc.doc_format
             )
@@ -116,7 +114,7 @@ class HtmlConverter(BaseConverter):
     EXTENSION = ".html"
 
     def convert(self, libdoc: LibraryDoc, output):
-        if int(RF_VERSION[0]) >= 4:
+        if int(ROBOT_VERSION[0]) >= 4:
             libdoc.convert_docs_to_html()
         libdoc.save(output, "HTML")
 
@@ -126,7 +124,7 @@ class XmlHtmlConverter(BaseConverter):
     EXTENSION = ".html"
 
     def convert(self, libdoc: LibraryDoc, output):
-        if int(RF_VERSION[0]) <= 3:
+        if int(ROBOT_VERSION[0]) <= 3:
             libdoc.save(output, "XML:HTML")
         else:
             libdoc.convert_docs_to_html()
@@ -202,7 +200,7 @@ class RestConverter(BaseConverter):
         with writer.field(keyword.name):
             fields = []
             if keyword.args:
-                if int(RF_VERSION[0]) <= 3:
+                if int(ROBOT_VERSION[0]) <= 3:
                     args = (self.escape_string(arg) for arg in keyword.args)
                     fields.append(("Arguments", ", ".join(args)))
                 else:
@@ -221,7 +219,7 @@ class RestHtmlConverter(RestConverter):
     EXTENSION = ".rst"
 
     def convert(self, libdoc: LibraryDoc, output):
-        if int(RF_VERSION[0]) <= 3:
+        if int(ROBOT_VERSION[0]) <= 3:
             DocFormatter = htmlwriter.DocFormatter
             formatter = DocFormatter(libdoc.keywords, libdoc.doc, libdoc.doc_format)
         else:
@@ -242,7 +240,7 @@ class RestHtmlConverter(RestConverter):
             init.doc = self._raw_html(formatter.html(init.doc))
         for kw in libdoc.keywords:
             kw.doc = self._raw_html(formatter.html(kw.doc))
-        if int(RF_VERSION[0]) >= 4:
+        if int(ROBOT_VERSION[0]) >= 4:
             for type in libdoc.data_types:
                 type.doc = self._raw_html(formatter.html(type.doc))
 
@@ -253,3 +251,10 @@ class RestHtmlConverter(RestConverter):
         for line in content.splitlines():
             output.append(f"   {line}")
         return "\n".join(output)
+
+class LibspecConverter(BaseConverter):
+    NAME = "libspec"
+    EXTENSION = ".libspec"
+
+    def convert(self, libdoc: LibraryDoc, output):
+        libdoc.save(output, "LIBSPEC")
